@@ -53,13 +53,13 @@ class_declaration:
     docucomment(?)
     exposure_specifier(?) class_modifier(s?) 'class' class_name 
         cnick(?)
-        class_extension(?)
+        class_inheritance(?)
         class_attribute(s?)
     '{'
         declaration_statement[
             class  => $item{class_name}, 
             cnick  => $item{'cnick(?)'}[0],
-            parent => $item{'class_extension(?)'}[0],
+            parent => $item{'class_inheritance(?)'}[0],
         ](s?)
     '}'
     { Clownfish::Parser->new_class( \%item, \%arg ) }
@@ -70,8 +70,8 @@ class_modifier:
     | 'final'
     { $item[1] }
 
-class_extension:
-    'extends' class_name
+class_inheritance:
+    'inherits' class_name
     { $item[2] }
 
 class_attribute:
@@ -373,8 +373,8 @@ sub simple_or_composite_type {
     if ( !@$postfixes ) {
         if ($nullable) {
             my $type_class = ref($simple_type);
-            confess "$type_class can't be 'nullable'" unless
-                $simple_type->isa("Clownfish::Type::Object");
+            confess "$type_class can't be 'nullable'"
+                unless $simple_type->isa("Clownfish::Type::Object");
             $simple_type->set_nullable($nullable);
         }
         return $simple_type;
@@ -486,7 +486,7 @@ sub new_class {
         parcel            => $parcel,
         class_name        => $item->{class_name},
         cnick             => $item->{'cnick(?)'}[0],
-        parent_class_name => $item->{'class_extension(?)'}[0],
+        parent_class_name => $item->{'class_inheritance(?)'}[0],
         member_vars       => \@member_vars,
         functions         => \@functions,
         methods           => \@methods,
@@ -563,4 +563,3 @@ This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
-
