@@ -8,7 +8,7 @@
 #include "KinoSearch/Index/SegReader.h"
 #include "KinoSearch/Util/PriorityQueue.h"
 
-/* Empty out, then refill the Queue, seeking all elements to [target]. */
+// Empty out, then refill the Queue, seeking all elements to [target]. 
 static void
 S_refresh_lex_q(SegLexQueue *lex_q, VArray *seg_lexicons, Obj *target);
 
@@ -22,15 +22,16 @@ PolyLex_new(const CharBuf *field, VArray *sub_readers)
 PolyLexicon*
 PolyLex_init(PolyLexicon *self, const CharBuf *field, VArray *sub_readers)
 {
-    u32_t i;
-    u32_t num_sub_readers = VA_Get_Size(sub_readers);
+    uint32_t i;
+    uint32_t num_sub_readers = VA_Get_Size(sub_readers);
     VArray *seg_lexicons  = VA_new(num_sub_readers);
 
-    /* Init. */
+    // Init. 
+    Lex_init((Lexicon*)self, field);
     self->term            = NULL;
     self->lex_q           = SegLexQ_new(num_sub_readers);
 
-    /* Derive. */
+    // Derive. 
     for (i = 0; i < num_sub_readers; i++) {
         LexiconReader *lex_reader = (LexiconReader*)VA_Fetch(sub_readers, i);
         if (lex_reader && CERTIFY(lex_reader, LEXICONREADER)) {
@@ -42,9 +43,6 @@ PolyLex_init(PolyLexicon *self, const CharBuf *field, VArray *sub_readers)
     }
     self->seg_lexicons  = seg_lexicons;
 
-    /* Assign. */
-    self->field         = CB_Clone(field);
-
     PolyLex_Reset(self);
 
     return self;
@@ -55,7 +53,6 @@ PolyLex_destroy(PolyLexicon *self)
 {
     DECREF(self->seg_lexicons);
     DECREF(self->lex_q);
-    DECREF(self->field);
     DECREF(self->term);
     SUPER_DESTROY(self, POLYLEXICON);
 }
@@ -63,16 +60,16 @@ PolyLex_destroy(PolyLexicon *self)
 static void
 S_refresh_lex_q(SegLexQueue *lex_q, VArray *seg_lexicons, Obj *target)
 {
-    u32_t i, max;
+    uint32_t i, max;
 
-    /* Empty out the queue. */
+    // Empty out the queue. 
     while (1) {
         SegLexicon *seg_lex = (SegLexicon*)SegLexQ_Pop(lex_q);
         if (seg_lex == NULL) break;
         DECREF(seg_lex);
     }
 
-    /* Refill the queue. */
+    // Refill the queue. 
     for (i = 0, max = VA_Get_Size(seg_lexicons); i < max; i++) {
         SegLexicon *const seg_lexicon 
             = (SegLexicon*)VA_Fetch(seg_lexicons, i);
@@ -86,19 +83,19 @@ S_refresh_lex_q(SegLexQueue *lex_q, VArray *seg_lexicons, Obj *target)
 void
 PolyLex_reset(PolyLexicon *self)
 {
-    u32_t i;
+    uint32_t i;
     VArray *seg_lexicons = self->seg_lexicons;
-    u32_t   num_segs     = VA_Get_Size(seg_lexicons);
+    uint32_t   num_segs     = VA_Get_Size(seg_lexicons);
     SegLexQueue *lex_q  = self->lex_q;
 
-    /* Empty out the queue. */
+    // Empty out the queue. 
     while (1) {
         SegLexicon *seg_lex = (SegLexicon*)SegLexQ_Pop(lex_q);
         if (seg_lex == NULL) break;
         DECREF(seg_lex);
     }
 
-    /* Fill the queue with valid SegLexicons. */
+    // Fill the queue with valid SegLexicons. 
     for (i = 0; i < num_segs; i++) {
         SegLexicon *const seg_lexicon 
             = (SegLexicon*)VA_Fetch(seg_lexicons, i);
@@ -120,13 +117,13 @@ PolyLex_next(PolyLexicon *self)
     SegLexQueue *lex_q   = self->lex_q;
     SegLexicon *top_seg_lexicon = (SegLexicon*)SegLexQ_Peek(lex_q);
     
-    /* Churn through queue items with equal terms. */
+    // Churn through queue items with equal terms. 
     while (top_seg_lexicon != NULL) {
         Obj *const candidate = SegLex_Get_Term(top_seg_lexicon); 
         if (   (candidate && !self->term)
             || Obj_Compare_To(self->term, candidate) != 0 
         ) {
-            /* Succeed if the next item in the queue has a different term. */
+            // Succeed if the next item in the queue has a different term. 
             DECREF(self->term);
             self->term = Obj_Clone(candidate);
             return true;
@@ -141,7 +138,7 @@ PolyLex_next(PolyLexicon *self)
         }
     }
 
-    /* If queue is empty, iterator is finished. */
+    // If queue is empty, iterator is finished. 
     DECREF(self->term);
     self->term = NULL;
     return false;
@@ -158,7 +155,7 @@ PolyLex_seek(PolyLexicon *self, Obj *target)
         return;
     }
 
-    /* Refresh the queue, set vars. */
+    // Refresh the queue, set vars. 
     S_refresh_lex_q(lex_q, seg_lexicons, target);
     {
         SegLexicon *least = (SegLexicon*)SegLexQ_Peek(lex_q);
@@ -170,10 +167,10 @@ PolyLex_seek(PolyLexicon *self, Obj *target)
         }
     }
 
-    /* Scan up to the real target. */
+    // Scan up to the real target. 
     do {
         if (self->term) {
-            const i32_t comparison = Obj_Compare_To(self->term, target);
+            const int32_t comparison = Obj_Compare_To(self->term, target);
             if (comparison >= 0) { break; }
         }
     } while (PolyLex_Next(self));
@@ -185,14 +182,14 @@ PolyLex_get_term(PolyLexicon *self)
     return self->term;
 }
 
-u32_t
+uint32_t
 PolyLex_get_num_seg_lexicons(PolyLexicon *self)
 {
     return VA_Get_Size(self->seg_lexicons);
 }
 
 SegLexQueue*
-SegLexQ_new(u32_t max_size)
+SegLexQ_new(uint32_t max_size)
 {
     SegLexQueue *self = (SegLexQueue*)VTable_Make_Obj(SEGLEXQUEUE);
     return (SegLexQueue*)PriQ_init((PriorityQueue*)self, max_size);
