@@ -35,7 +35,7 @@ Hits_destroy(Hits *self)
     SUPER_DESTROY(self, HITS);
 }
 
-Obj*
+HitDoc*
 Hits_next(Hits *self)
 {
     MatchDoc *match_doc = (MatchDoc*)VA_Fetch(self->match_docs, self->offset);
@@ -48,10 +48,11 @@ Hits_next(Hits *self)
     }
     else {
         // Lazily fetch HitDoc, set score. 
-        Obj *doc = Searcher_Fetch_Doc(self->searcher,
-            match_doc->doc_id, match_doc->score, 0);
+        HitDoc *hit_doc = Searcher_Fetch_Doc(self->searcher,
+            match_doc->doc_id);
+        HitDoc_Set_Score(hit_doc, match_doc->score);
 
-        return doc;
+        return hit_doc;
     }
 }
 
