@@ -3,16 +3,16 @@
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Search/TermQuery.h"
-#include "KinoSearch/Schema.h"
-#include "KinoSearch/Search/Span.h"
 #include "KinoSearch/Index/DocVector.h"
 #include "KinoSearch/Index/SegReader.h"
 #include "KinoSearch/Index/PostingList.h"
 #include "KinoSearch/Index/PostingListReader.h"
+#include "KinoSearch/Index/Similarity.h"
 #include "KinoSearch/Index/TermVector.h"
+#include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/Compiler.h"
-#include "KinoSearch/Search/Searchable.h"
-#include "KinoSearch/Search/Similarity.h"
+#include "KinoSearch/Search/Searcher.h"
+#include "KinoSearch/Search/Span.h"
 #include "KinoSearch/Search/TermScorer.h"
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
@@ -87,38 +87,41 @@ TermQuery_to_string(TermQuery *self)
 }
 
 Compiler*
-TermQuery_make_compiler(TermQuery *self, Searchable *searchable, float boost) 
+TermQuery_make_compiler(TermQuery *self, Searcher *searcher, float boost) 
 {
-    return (Compiler*)TermCompiler_new((Query*)self, searchable, boost);
+    return (Compiler*)TermCompiler_new((Query*)self, searcher, boost);
 }
 
 /******************************************************************/
 
 TermCompiler*
-TermCompiler_new(Query *parent, Searchable *searchable, float boost)
+TermCompiler_new(Query *parent, Searcher *searcher, float boost)
 {
     TermCompiler *self = (TermCompiler*)VTable_Make_Obj(TERMCOMPILER);
-    return TermCompiler_init(self, parent, searchable, boost);
+    return TermCompiler_init(self, parent, searcher, boost);
 }
 
 TermCompiler*
-TermCompiler_init(TermCompiler *self, Query *parent, Searchable *searchable, 
+TermCompiler_init(TermCompiler *self, Query *parent, Searcher *searcher, 
                   float boost)
 {
-    Schema     *schema  = Searchable_Get_Schema(searchable);
+    Schema     *schema  = Searcher_Get_Schema(searcher);
     TermQuery  *tparent = (TermQuery*)parent;
     Similarity *sim     = Schema_Fetch_Sim(schema, tparent->field);
 
-    /* Try harder to get a Similarity if necessary. */
+    // Try harder to get a Similarity if necessary. 
     if (!sim) { sim = Schema_Get_Similarity(schema); }
 
-    /* Init. */
-    Compiler_init((Compiler*)self, parent, searchable, sim, boost);
+    // Init. 
+    Compiler_init((Compiler*)self, parent, searcher, sim, boost);
     self->normalized_weight = 0.0f;
     self->query_norm_factor = 0.0f;
 
-    /* Derive. */
-    self->idf = Sim_IDF(sim, searchable, tparent->field, tparent->term);
+    // Derive. 
+    int32_t doc_max  = Searcher_Doc_Max(searcher);
+    int32_t doc_freq = Searcher_Doc_Freq(searcher, tparent->field, 
+        tparent->term);
+    self->idf = Sim_IDF(sim, doc_freq, doc_max);
     
     /* The score of any document is approximately equal to:
      *
@@ -133,7 +136,7 @@ TermCompiler_init(TermCompiler *self, Query *parent, Searchable *searchable,
      */
     self->raw_weight = self->idf * self->boost;
 
-    /* Make final preparations. */
+    // Make final preparations. 
     TermCompiler_Normalize(self);
 
     return self;
@@ -225,27 +228,27 @@ TermCompiler_make_matcher(TermCompiler *self, SegReader *reader,
 }
 
 VArray*
-TermCompiler_highlight_spans(TermCompiler *self, Searchable *searchable, 
+TermCompiler_highlight_spans(TermCompiler *self, Searcher *searcher, 
                              DocVector *doc_vec, const CharBuf *field)
 {
     TermQuery *const parent = (TermQuery*)self->parent;
     VArray *spans = VA_new(0);
     TermVector *term_vector;
     I32Array *starts, *ends;
-    u32_t i, max;
-    UNUSED_VAR(searchable);
+    uint32_t i, max;
+    UNUSED_VAR(searcher);
 
     if (!CB_Equals(parent->field, (Obj*)field)) return spans;
 
-    /* Add all starts and ends. */
+    // Add all starts and ends. 
     term_vector = DocVec_Term_Vector(doc_vec, field, (CharBuf*)parent->term);
     if (!term_vector) return spans;
 
     starts = TV_Get_Start_Offsets(term_vector);
     ends   = TV_Get_End_Offsets(term_vector);
     for (i = 0, max = I32Arr_Get_Size(starts); i < max; i++) {
-        i32_t start  = I32Arr_Get(starts, i);
-        i32_t length = I32Arr_Get(ends, i) - start;
+        int32_t start  = I32Arr_Get(starts, i);
+        int32_t length = I32Arr_Get(ends, i) - start;
         VA_Push(spans, 
             (Obj*)Span_new(start, length, TermCompiler_Get_Weight(self)) );
     }
