@@ -8,7 +8,14 @@ __END__
 __BINDING__
 
 my $synopis = <<'END_SYNOPSIS';
-    # abstract base class
+
+    my @sortable;
+    for my $field ( @{ $schema->all_fields } ) {
+        my $type = $schema->fetch_type($field);
+        next unless $type->sortable;
+        push @sortable, $field;
+    }
+
 END_SYNOPSIS
 
 Clownfish::Binding::Perl::Class->register(
@@ -16,12 +23,10 @@ Clownfish::Binding::Perl::Class->register(
     class_name   => "KinoSearch::Plan::FieldType",
     bind_methods => [
         qw(
-            Set_Boost
             Get_Boost
-            Set_Indexed
             Indexed
-            Set_Stored
             Stored
+            Sortable
             Binary
             Compare_Values
             )
@@ -31,12 +36,10 @@ Clownfish::Binding::Perl::Class->register(
         synopsis => $synopis,
         methods  => [
             qw(
-                set_boost
                 get_boost
-                set_indexed
                 indexed
-                set_stored
                 stored
+                sortable
                 binary
                 )
         ],
