@@ -13,9 +13,8 @@
 #include "KinoSearch/Object/Host.h"
 #include "KinoSearch/Store/InStream.h"
 
-kino_Obj*
-kino_DefDocReader_fetch(kino_DefaultDocReader *self, int32_t doc_id, 
-                        float score, int32_t offset)
+kino_HitDoc*
+kino_DefDocReader_fetch_doc(kino_DefaultDocReader *self, int32_t doc_id)
 {
     kino_Schema   *const schema = self->schema;
     kino_InStream *const dat_in = self->dat_in;
@@ -104,9 +103,9 @@ kino_DefDocReader_fetch(kino_DefaultDocReader *self, int32_t doc_id,
     SvREFCNT_dec(field_name_sv);
 
     {
-        kino_HitDoc *retval = kino_HitDoc_new(fields, doc_id + offset, score);
+        kino_HitDoc *retval = kino_HitDoc_new(fields, doc_id, 0.0);
         SvREFCNT_dec((SV*)fields);
-        return (kino_Obj*)retval;
+        return retval;
     }
 }
 
